//## begin module%1.4%.codegen_version preserve=yes
//   Read the documentation to learn more about C++ code generator
//   versioning.
//## end module%1.4%.codegen_version

//## begin module%38316E199978.cm preserve=no
//	This is version 2.2 release dated Sep 2009
//## end module%38316E199978.cm

//## begin module%38316E199978.cp preserve=no
//	Astrophysics Science Division,
//	NASA/ Goddard Space Flight Center
//	HEASARC
//	http://heasarc.gsfc.nasa.gov
//	e-mail: ccfits@legacy.gsfc.nasa.gov
//
//	Original author: Ben Dorman
//## end module%38316E199978.cp

//## Module: FitsError%38316E199978; Package specification
//## Subsystem: CCfits::FITS%393411910327
//## Source file: /local/data/xerxes1/gordon/headas/heacore/CCfits/FitsError.h

#ifndef FITSERROR_H
#define FITSERROR_H 1

//## begin module%38316E199978.additionalIncludes preserve=no
#include <exception>
#include <iostream>
//## end module%38316E199978.additionalIncludes

//## begin module%38316E199978.includes preserve=yes
//## end module%38316E199978.includes

//## begin module%38316E199978.declarations preserve=no
//## end module%38316E199978.declarations

//## begin module%38316E199978.additionalDeclarations preserve=yes
//#include <exception>
//#include <iostream>
//#include <stl.h>
#include <string>
using std::string;
//## end module%38316E199978.additionalDeclarations


namespace CCfits {
  //## begin CCfits%37FE4140B6F8.initialDeclarations preserve=yes
        
  /*! \class FitsException
        
        @ingroup FITSexcept
        @brief FitsException is the base class for all exceptions thrown by this library.
        
        All exceptions derived from this class can be caught by a single 'catch' clause
        catching FitsException by reference (which is the point of this base class design).
        
        
        A static "verboseMode" parameter is provided by the FITS class to 
        control diagnostics - if FITS::verboseMode() is true, all diagnostics
        are printed (for debugging purposes). If not, then a boolean <I>silent</I>
        determines printing of messages. Each exception derived from FitsException
        must define a default value for the <I>silent</I> parameter.
  
  */
  
  /*! \fn  FitsException::FitsException(const string& diag, bool& silent)
        
        \param diag A diagnostic string to be printed optionally.
        \param silent A boolean controlling the printing of messages
  */      
 
  /*! \fn const string& FitsException::message () const

       \brief returns the error message
       
       This returns the diagnostic error message associated with the
       exception object, and which is accessible regardless of the verboseMode
       and silent flag settings.  
  */     
      
    /*! \class FitsError
        
        @ingroup FITSexcept
        @brief FitsError is the exception thrown by non-zero cfitsio status codes.
        
  
  */
  
  /*! \fn  FitsError::FitsError(int errornum, bool silent)
  
        \brief ctor for cfitsio exception: translates status code into cfitsio error message
        
        The exception prefixes the string "Fits Error: " to the message printed by cfitsio.
        
        \param errornum The cfitsio status code produced by the error.
        \param silent A boolean controlling the printing of messages
  */      

  /*! \class FitsFatal
        
        @ingroup FITSexcept
        @brief [potential] base class for exceptions to be thrown on internal library error.
        
        As of this version there are no subclasses. This error requests that the
        user reports this circumstance to HEASARC.
  
  */
  
  /*! \fn  FitsFatal::FitsFatal(const string& diag)
        
        \brief Prints a message starting "*** CCfits Fatal Error: ..." and calls <i>terminate()</i>
        
        \param diag A diagnostic string to be printed identifying the context of the error.
  */ 
      
  //## end CCfits%37FE4140B6F8.initialDeclarations

  //## Class: FitsException%3946517C0152
  //	Base class for exceptions generated by CCfits that don't
  //	return FITS error codes (for example, array errors or seek errors).
  //## Category: CCfits::FITS%393416E90118
  //## Subsystem: CCfits::FITS%393411910327
  //## Persistence: Transient
  //## Cardinality/Multiplicity: n



  class FitsException 
  {
    public:
      //## Constructors (specified)
        //## Operation: FitsException%394651CD036A
        FitsException (const string& msg, bool& silent);


      //## Other Operations (specified)
        //## Operation: message%476984AE0217
        const string& message () const;

    protected:

      //## Other Operations (specified)
        //## Operation: addToMessage%476985360089
        void addToMessage (const string& msgQual);

    private:
    private: //## implementation
      // Data Members for Class Attributes

        //## Attribute: message%4769837B01EF
        //## begin CCfits::FitsException::message%4769837B01EF.attr preserve=no  protected: string {U} 
        string m_message;
        //## end CCfits::FitsException::message%4769837B01EF.attr

  };

  //## Class: FitsError%38316DEA5418
  //## Category: CCfits::FITS%393416E90118
  //## Subsystem: CCfits::FITS%393411910327
  //## Persistence: Transient
  //## Cardinality/Multiplicity: n



  class FitsError : public FitsException  //## Inherits: <unnamed>%399170BD017D
  {
    public:
      //## Constructors (specified)
        //## Operation: FitsError%38316F6835A0
        FitsError (int errornum, bool silent = true);

    protected:
    private:

      //## Other Operations (specified)
        //## Operation: printMsg%38316FECD898
        void printMsg (int error);

    private: //## implementation
  };

  //## Class: FitsFatal%3AFAA81000D0
  //## Category: CCfits::FITS%393416E90118
  //## Subsystem: CCfits::FITS%393411910327
  //## Persistence: Transient
  //## Cardinality/Multiplicity: n



  class FitsFatal 
  {
    public:
      //## Constructors (specified)
        //## Operation: FitsFatal%3AFAA825005B
        FitsFatal (const string& diag);

    protected:
    private:
    private: //## implementation
  };

  // Class CCfits::FitsException 


  //## Other Operations (inline)
  inline const string& FitsException::message () const
  {
    //## begin CCfits::FitsException::message%476984AE0217.body preserve=yes
     return m_message;
    //## end CCfits::FitsException::message%476984AE0217.body
  }

  // Class CCfits::FitsError 

  // Class CCfits::FitsFatal 

} // namespace CCfits

//## begin module%38316E199978.epilog preserve=yes
//## end module%38316E199978.epilog


#endif
